@@ -1,110 +1,3 @@
-#  File limma/R/norm.R
-#  Part of the limma package for R, http://www.bioconductor.org
-#
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  A copy of the GNU General Public License is available at
-#  http://www.r-project.org/Licenses/
-
-
-#	LOESS FUNCTIONS
-
-loessFit <- function(y, x, weights=NULL, span=0.3, bin=0.01/(2-is.null(weights)), iterations=4) {
-#	Fast loess fit for simple x and y
-#	This function uses stats:::lowess if no weights and stats:::loess otherwise.
-#	It is intended to give a streamlined common interface to the two functions.
-#	Gordon Smyth
-#	28 June 2003.  Last revised 16 Feb 2004.
-
-	n <- length(y)
-	out <- list(fitted=rep(NA,n),residuals=rep(NA,n))
-	obs <- is.finite(y) & is.finite(x)
-	xobs <- x[obs]
-	yobs <- y[obs]
-	nobs <- length(yobs)
-	if(nobs==0) return(out)
-	if(is.null(weights)) {
-		o <- order(xobs)
-		oo <- order(o)
-		iter <- iterations-1
-		delta = bin * diff(range(xobs))
-#		The .C("lowess" call is copied from stats:::lowess
-		smoothy <- .C("lowess", x = as.double(xobs[o]), as.double(yobs[o]), 
-			nobs, as.double(span), as.integer(iter), as.double(delta), 
-			y = double(nobs), double(nobs), double(nobs), PACKAGE = "stats")$y[oo]
-		out$fitted[obs] <- smoothy
-		out$residuals[obs] <- yobs-smoothy
-	} else {
-		weights[!is.finite(weights)] <- 0
-		wobs <- weights[obs]
-		if(sum(wobs>0) < 4+1/span) {
-			fit <- lm.wfit(cbind(1,xobs),yobs,wobs)
-		} else {
-#			Suppress warning "k-d tree limited by memory"
-#			oldopt <- options(warning.expression=expression())
-			oldopt <- options(warn=-1)
-			on.exit(options(oldopt))
-			fit <- .vsimpleLoess(y=yobs, x=xobs, weights=wobs, span=span, degree=1,
-				cell=bin/span, iterations=iterations)
-		}
-		out$fitted[obs] <- fit$fitted
-		out$residuals[obs] <- fit$residuals
-	}
-	out
-}
-
-.vsimpleLoess <- function (y, x, weights, span=0.75, degree=2, cell=0.2, iterations=1)
-#	This function is an edited copy, with some steps removed that are not needed here,
-#  of the R function stats:::simpleLoess by BD Ripley
-#	Gordon Smyth
-#	28 June 2003.  Last modified 27 Feb 2008.
-{
-	statistics <- "none"
-	surface <- "interpolate"
-	surf.stat <- paste(surface, statistics, sep = "/")
-	D <- 1
-	N <- NROW(x)
-	if (!N || !D) stop("invalid `x'")
-	if (!length(y)) stop("invalid `y'")
-	x <- as.matrix(x)
-	max.kd <- max(N, 200)
-	robust <- rep(1, N)
-	sum.drop.sqr <- 0
-	sum.parametric <- 0
-	nonparametric <- 1
-	order.parametric <- 1
-	order.drop.sqr <- 2
-	if (iterations) 
-		for (j in 1:iterations) {
-			robust <- weights * robust
-			z <- .C("loess_raw", as.double(y), as.double(x), 
-				as.double(weights), as.double(robust), as.integer(D), 
-				as.integer(N), as.double(span), as.integer(degree), 
-				as.integer(nonparametric), as.integer(order.drop.sqr), 
-				as.integer(sum.drop.sqr), as.double(span * cell), 
-				as.character(surf.stat), fitted.values = double(N), 
-				parameter = integer(7), a = integer(max.kd), 
-				xi = double(max.kd), vert = double(2 * D), vval = double((D + 
-				1) * max.kd), diagonal = double(N), trL = double(1), 
-				delta1 = double(1), delta2 = double(1), as.integer(surf.stat == 
-				"interpolate/exact"), PACKAGE = "stats")
-			fitted.residuals <- y - z$fitted.values
-			if (j < iterations) 
-				robust <- .Fortran("lowesw", as.double(fitted.residuals), 
-				as.integer(N), robust = double(N), integer(N), 
-				PACKAGE = "stats")$robust
-		}
-	list(fitted = z$fitted.values, residuals = fitted.residuals)
-}
-
 #  WITHIN ARRAY NORMALIZATION
 
 MA.RG <- function(object, bc.method="subtract", offset=0) {
@@ -145,7 +38,7 @@ RG.MA <- function(object) {
 normalizeWithinArrays <- function(object,layout=object$printer,method="printtiploess",weights=object$weights,span=0.3,iterations=4,controlspots=NULL,df=5,robust="M",bc.method="subtract",offset=0)
 #	Within array normalization
 #	Gordon Smyth
-#	2 March 2003.  Last revised 2 September 2006.
+#	2 March 2003.  Last revised 16 March 2013.
 {
 #	Check input arguments
 #	and get non-intensity dependent methods out of the way
@@ -242,7 +135,7 @@ normalizeWithinArrays <- function(object,layout=object$printer,method="printtipl
 			}
 		},
 		robustspline = {
-			if(is.null(layout)) stop("Layout argument not specified")
+#			if(is.null(layout)) stop("Layout argument not specified")
 			for (j in 1:narrays)
 				object$M[,j] <- normalizeRobustSpline(object$M[,j],object$A[,j],layout,df=df,method=robust)
 		}
@@ -250,17 +143,22 @@ normalizeWithinArrays <- function(object,layout=object$printer,method="printtipl
 	object
 }
 
-normalizeRobustSpline <- function(M,A,layout,df=5,method="M") {
+normalizeRobustSpline <- function(M,A,layout=NULL,df=5,method="M") {
 #	Robust spline normalization
 #	Gordon Smyth
-#	27 April 2003.  Last revised 2 Feb 2007.
+#	27 April 2003.  Last revised 29 Nov 2012.
 
 	require(MASS)
 	require(splines)
-	ngrids <- round(layout$ngrid.r * layout$ngrid.c)
-	nspots <- round(layout$nspot.r * layout$nspot.c)
-	if(ngrids < 1) stop("layout incorrectly specified")
-	if(nspots < df+1) stop("too few spots in each print-tip block")
+	if(is.null(layout)) {
+		ngrids <- 1
+		nspots <- length(M)
+	} else {
+		ngrids <- round(layout$ngrid.r * layout$ngrid.c)
+		nspots <- round(layout$nspot.r * layout$nspot.c)
+		if(ngrids < 1) stop("layout incorrectly specified")
+		if(nspots < df+1) stop("too few spots in each print-tip block")
+	}
 
 #	Global splines
 	O <- is.finite(M) & is.finite(A)
