@@ -3,8 +3,13 @@
 topTable <- function(fit,coef=NULL,number=10,genelist=fit$genes,adjust.method="BH",sort.by="B",resort.by=NULL,p.value=1,lfc=0,confint=FALSE)
 #	Summary table of top genes, object-orientated version
 #	Gordon Smyth
-#	4 August 2003.  Last modified 19 Jan 2012.
+#	4 August 2003.  Last modified 7 April 2013.
 {
+#	Check fit
+	if(!is(fit,"MArrayLM")) stop("fit must be an MArrayLM object")
+	if(is.null(fit$coefficients)) stop("coefficients not found in fit object")
+	if(is.null(fit$stdev.unscaled)) stop("stdev.unscaled not found in fit object")
+
 	if(is.null(coef)) coef <- 1:ncol(fit)
 	if(length(coef)>1) {
 		coef <- unique(coef)
